DARK_BLUE = 0x10 # dark blue
DARK_GREEN = 0x20 # dark green
DARK_SKYBLUE = 0x30 # dark skyblue
DARK_RED = 0x40 # dark red
DARK_PINK = 0x50 # dark pink
DARK_YELLOW = 0x60 # dark yellow
DARK_WHITE = 0x70 # dark white
DARK_GRAY = 0x80 # dark gray
BLACK = 0x00 #black
BLUE = 0x90 # blue
GREEN = 0xa0 # green
SKYBLUE = 0xb0 # skyblue
RED = 0xc0 # red
PINK = 0xd0 # pink
YELLOW = 0xe0 # yellow
WHITE = 0xf0 # white